import requests
import unittest
from unittest import mock

import allmusic


class TestAlbumReview(unittest.TestCase):
    # This is the only test that actually makes a request to allmusic.com
    def test_live_request(self):
        review = allmusic.getAlbumReviewForAllMusicUrl(
            'https://www.allmusic.com/album/mw0002927433')
        self.assertEqual(review.artist, 'The Kills')
        self.assertEqual(review.name, 'Ash & Ice')
        self.assertEqual(review.rating, 7)
        self.assertEqual(
            review.review_url,
            'https://www.allmusic.com/album/ash-ice-mw0002927433')
        self.assertEqual(review.review_author, 'Heather Phares')
        pass


if __name__ == '__main__':
    unittest.main()



import extruct
import requests
import w3lib.html

SCHEMA_RATING_URL = "https://schema.org/Rating"
SCHEMA_MUSIC_ALBUM_URL = "https://schema.org/MusicAlbum"
SCHEMA_MUSIC_GROUP_URL = "https://schema.org/MusicGroup"
SCHEMA_REVIEW_URL = "https://schema.org/Review"


class AlbumReview:
    """
    Class representing the fetched review

    Includes the following fields:
    - artist
    - name
    - rating
    - review_url
    - review_author
    - review_body
    """

    def __init__(self, microdata):
        for data in microdata:
            type = data.get('type')
            properties = data.get('properties')

            if not type or not properties:
                continue

            if type == SCHEMA_RATING_URL:
                self.rating = int(properties.get('ratingValue'))
                continue

            if type == SCHEMA_MUSIC_ALBUM_URL:
                self.review_url = properties.get('url')
                self.name = properties.get('name')

                artist = properties.get('byArtist')
                if artist and artist.get('type') == SCHEMA_MUSIC_GROUP_URL:
                    artist_properties = artist.get('properties')
                    if artist_properties:
                        self.artist = artist_properties.get('name')

                review = properties.get('review')
                if review and review.get('type') == SCHEMA_REVIEW_URL:
                    review_properties = review.get('properties')
                    if review_properties:
                        self.review_author = review_properties.get('author')
                        self.review_body = review_properties.get('reviewBody')
                    else:
                        print('no review properties')
                else:
                    print('no review found')


def isValidAllMusicAlbumReviewUrl(url):
    return True


def fetchAlbumReviewHTML(url):
    if not isValidAllMusicAlbumReviewUrl(url):
        raise ValueError('Invalid AllMusic album url')

    headers = {'User-Agent': 'AllMusic Python Scraper'}
    r = requests.get(url, headers=headers)
    if r.status_code != 200:
        raise IndexError(
            'Non-200 status code from Allmusic %s' % r.status_code)

    return r.text


def getAlbumReviewForAllMusicUrl(url):
    """
    Get `AlbumReview` object for an AllMusic review URL
    """
    html = fetchAlbumReviewHTML(url)
    base_url = w3lib.html.get_base_url(html, url)
    data = extruct.extract(html, base_url=base_url)
    microdata = data.get('microdata')
    if not microdata:
        raise IndexError('No microdata found in URL: %s' % url)

    return AlbumReview(microdata)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("requirements.txt", "r") as fr:
    requirements = fr.read().splitlines()

setuptools.setup(
    name="allmusic",
    version="0.0.1",
    author="Filipe Fortes",
    author_email="accounts@fortes.com",
    description="AllMusic review scraper",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/fortes/allmusic",
    license='MIT',
    platforms='ALL',
    packages=setuptools.find_packages(),
    install_requires=requirements,
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        'Topic :: Internet :: WWW/HTTP :: Indexing/Search',
    ])
